pub struct MatchmakingData {
pub opponents: Vec<MatchmakingOpponent>,
pub is_free_refresh_available: bool,
}Fields
opponents: Vec<MatchmakingOpponent>is_free_refresh_available: boolTrait Implementations
Sourceimpl Clone for MatchmakingData
impl Clone for MatchmakingData
Sourcefn clone(&self) -> MatchmakingData
fn clone(&self) -> MatchmakingData
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for MatchmakingData
impl CustomType for MatchmakingData
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for MatchmakingData
impl Debug for MatchmakingData
Sourceimpl Default for MatchmakingData
impl Default for MatchmakingData
Sourcefn default() -> MatchmakingData
fn default() -> MatchmakingData
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for MatchmakingData
impl<'de> Deserialize<'de> for MatchmakingData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MatchmakingData
impl JsonSchema for MatchmakingData
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MatchmakingData
impl PartialEq for MatchmakingData
Sourceimpl Serialize for MatchmakingData
impl Serialize for MatchmakingData
Sourceimpl Tsify for MatchmakingData
impl Tsify for MatchmakingData
const DECL: &'static str = "export interface MatchmakingData {\n opponents: MatchmakingOpponent[];\n is_free_refresh_available: boolean;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for MatchmakingData
impl StructuralPartialEq for MatchmakingData