pub struct MatchmakingOpponent {
pub opponent: OpponentPreview,
pub win_rating_increase: i64,
pub lose_rating_decrease: i64,
}Fields
opponent: OpponentPreviewwin_rating_increase: i64lose_rating_decrease: i64Trait Implementations
Sourceimpl Clone for MatchmakingOpponent
impl Clone for MatchmakingOpponent
Sourcefn clone(&self) -> MatchmakingOpponent
fn clone(&self) -> MatchmakingOpponent
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for MatchmakingOpponent
impl CustomType for MatchmakingOpponent
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for MatchmakingOpponent
impl Debug for MatchmakingOpponent
Sourceimpl Default for MatchmakingOpponent
impl Default for MatchmakingOpponent
Sourcefn default() -> MatchmakingOpponent
fn default() -> MatchmakingOpponent
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for MatchmakingOpponent
impl<'de> Deserialize<'de> for MatchmakingOpponent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MatchmakingOpponent
impl JsonSchema for MatchmakingOpponent
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MatchmakingOpponent
impl PartialEq for MatchmakingOpponent
Sourceimpl Serialize for MatchmakingOpponent
impl Serialize for MatchmakingOpponent
Sourceimpl Tsify for MatchmakingOpponent
impl Tsify for MatchmakingOpponent
const DECL: &'static str = "export interface MatchmakingOpponent {\n opponent: OpponentPreview;\n win_rating_increase: number;\n lose_rating_decrease: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for MatchmakingOpponent
impl StructuralPartialEq for MatchmakingOpponent