pub struct Opponent {
pub user: User,
pub character: Character,
}Fields
user: Usercharacter: CharacterTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Opponent
impl<'de> Deserialize<'de> for Opponent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromWasmAbi for Opponentwhere
Self: DeserializeOwned,
impl FromWasmAbi for Opponentwhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for Opponent
impl IntoWasmAbi for Opponent
Sourceimpl JsonSchema for Opponent
impl JsonSchema for Opponent
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for Opponentwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for Opponentwhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for Opponent
impl OptionIntoWasmAbi for Opponent
Sourceimpl RefFromWasmAbi for Opponentwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for Opponentwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourceimpl Tsify for Opponent
impl Tsify for Opponent
const DECL: &'static str = "export interface Opponent {\n user: User;\n character: Character;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for Opponentwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for Opponentwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for Opponent
impl VectorIntoWasmAbi for Opponent
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
impl Eq for Opponent
impl StructuralPartialEq for Opponent