pub struct PVPState {
pub opponent_state: Box<OpponentState>,
pub vassal: Option<Vassal>,
pub rating_change: Option<RatingChange>,
pub stars_change: Option<StarsChange>,
}Fields
opponent_state: Box<OpponentState>vassal: Option<Vassal>rating_change: Option<RatingChange>stars_change: Option<StarsChange>Trait Implementations
Sourceimpl CustomType for PVPState
impl CustomType for PVPState
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl<'de> Deserialize<'de> for PVPState
impl<'de> Deserialize<'de> for PVPState
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PVPState
impl JsonSchema for PVPState
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Tsify for PVPState
impl Tsify for PVPState
const DECL: &'static str = "export interface PVPState {\n opponent_state: OpponentState;\n vassal: Vassal | null;\n rating_change: RatingChange | null;\n stars_change: StarsChange | null;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for PVPState
impl StructuralPartialEq for PVPState