pub struct RatingChange {
pub winner_rating_increase: i64,
pub loser_rating_decrease: i64,
}Fields
winner_rating_increase: i64loser_rating_decrease: i64Trait Implementations
Sourceimpl Clone for RatingChange
impl Clone for RatingChange
Sourcefn clone(&self) -> RatingChange
fn clone(&self) -> RatingChange
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for RatingChange
impl CustomType for RatingChange
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for RatingChange
impl Debug for RatingChange
Sourceimpl<'de> Deserialize<'de> for RatingChange
impl<'de> Deserialize<'de> for RatingChange
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RatingChange
impl JsonSchema for RatingChange
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RatingChange
impl PartialEq for RatingChange
Sourceimpl Serialize for RatingChange
impl Serialize for RatingChange
Sourceimpl Tsify for RatingChange
impl Tsify for RatingChange
const DECL: &'static str = "export interface RatingChange {\n winner_rating_increase: number;\n loser_rating_decrease: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for RatingChange
impl StructuralPartialEq for RatingChange