pub struct VassalPvpOpponent {
pub opponent: Opponent,
pub suzerain: Option<Opponent>,
}Fields
opponent: Opponentsuzerain: Option<Opponent>Trait Implementations
Sourceimpl Clone for VassalPvpOpponent
impl Clone for VassalPvpOpponent
Sourcefn clone(&self) -> VassalPvpOpponent
fn clone(&self) -> VassalPvpOpponent
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VassalPvpOpponent
impl Debug for VassalPvpOpponent
Sourceimpl<'de> Deserialize<'de> for VassalPvpOpponent
impl<'de> Deserialize<'de> for VassalPvpOpponent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<VassalPvpOpponent> for JsValuewhere
VassalPvpOpponent: Serialize,
impl From<VassalPvpOpponent> for JsValuewhere
VassalPvpOpponent: Serialize,
Sourcefn from(value: VassalPvpOpponent) -> Self
fn from(value: VassalPvpOpponent) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for VassalPvpOpponentwhere
Self: DeserializeOwned,
impl FromWasmAbi for VassalPvpOpponentwhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for VassalPvpOpponentwhere
VassalPvpOpponent: Serialize,
impl IntoWasmAbi for VassalPvpOpponentwhere
VassalPvpOpponent: Serialize,
Sourceimpl JsonSchema for VassalPvpOpponent
impl JsonSchema for VassalPvpOpponent
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for VassalPvpOpponentwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for VassalPvpOpponentwhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for VassalPvpOpponentwhere
VassalPvpOpponent: Serialize,
impl OptionIntoWasmAbi for VassalPvpOpponentwhere
VassalPvpOpponent: Serialize,
Sourceimpl PartialEq for VassalPvpOpponent
impl PartialEq for VassalPvpOpponent
Sourceimpl RefFromWasmAbi for VassalPvpOpponentwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for VassalPvpOpponentwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<VassalPvpOpponent>
type Anchor = SelfOwner<VassalPvpOpponent>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for VassalPvpOpponent
impl Serialize for VassalPvpOpponent
Sourceimpl Tsify for VassalPvpOpponent
impl Tsify for VassalPvpOpponent
const DECL: &'static str = "export interface VassalPvpOpponent {\n opponent: Opponent;\n suzerain: Opponent | null;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for VassalPvpOpponentwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for VassalPvpOpponentwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for VassalPvpOpponentwhere
VassalPvpOpponent: Serialize,
impl VectorIntoWasmAbi for VassalPvpOpponentwhere
VassalPvpOpponent: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribeVector for VassalPvpOpponent
impl WasmDescribeVector for VassalPvpOpponent
impl Eq for VassalPvpOpponent
impl StructuralPartialEq for VassalPvpOpponent