pub struct VassalPvpPlayersFindRequest {
pub character_id: Uuid,
}Fields
character_id: UuidTrait Implementations
Sourceimpl Clone for VassalPvpPlayersFindRequest
impl Clone for VassalPvpPlayersFindRequest
Sourcefn clone(&self) -> VassalPvpPlayersFindRequest
fn clone(&self) -> VassalPvpPlayersFindRequest
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VassalPvpPlayersFindRequest
impl Debug for VassalPvpPlayersFindRequest
Sourceimpl<'de> Deserialize<'de> for VassalPvpPlayersFindRequest
impl<'de> Deserialize<'de> for VassalPvpPlayersFindRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<VassalPvpPlayersFindRequest> for JsValuewhere
VassalPvpPlayersFindRequest: Serialize,
impl From<VassalPvpPlayersFindRequest> for JsValuewhere
VassalPvpPlayersFindRequest: Serialize,
Sourcefn from(value: VassalPvpPlayersFindRequest) -> Self
fn from(value: VassalPvpPlayersFindRequest) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for VassalPvpPlayersFindRequestwhere
Self: DeserializeOwned,
impl FromWasmAbi for VassalPvpPlayersFindRequestwhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for VassalPvpPlayersFindRequestwhere
VassalPvpPlayersFindRequest: Serialize,
impl IntoWasmAbi for VassalPvpPlayersFindRequestwhere
VassalPvpPlayersFindRequest: Serialize,
Sourceimpl JsonSchema for VassalPvpPlayersFindRequest
impl JsonSchema for VassalPvpPlayersFindRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for VassalPvpPlayersFindRequestwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for VassalPvpPlayersFindRequestwhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for VassalPvpPlayersFindRequestwhere
VassalPvpPlayersFindRequest: Serialize,
impl OptionIntoWasmAbi for VassalPvpPlayersFindRequestwhere
VassalPvpPlayersFindRequest: Serialize,
Sourceimpl RefFromWasmAbi for VassalPvpPlayersFindRequestwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for VassalPvpPlayersFindRequestwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<VassalPvpPlayersFindRequest>
type Anchor = SelfOwner<VassalPvpPlayersFindRequest>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Tsify for VassalPvpPlayersFindRequest
impl Tsify for VassalPvpPlayersFindRequest
const DECL: &'static str = "export interface VassalPvpPlayersFindRequest {\n character_id: Uuid;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for VassalPvpPlayersFindRequestwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for VassalPvpPlayersFindRequestwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for VassalPvpPlayersFindRequestwhere
VassalPvpPlayersFindRequest: Serialize,
impl VectorIntoWasmAbi for VassalPvpPlayersFindRequestwhere
VassalPvpPlayersFindRequest: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribeVector for VassalPvpPlayersFindRequest
impl WasmDescribeVector for VassalPvpPlayersFindRequest
impl Eq for VassalPvpPlayersFindRequest
impl StructuralPartialEq for VassalPvpPlayersFindRequest